using System;
using System.ComponentModel;
using System.ComponentModel.Design.Serialization;
using System.Globalization;
using System.Reflection;

namespace SharpDX.Design;

public class g : ExpandableObjectConverter
{
	public override bool CanConvertFrom(ITypeDescriptorContext context, Type sourceType)
	{
		if ((object)sourceType != typeof(string))
		{
			return base.CanConvertFrom(context, sourceType);
		}
		return true;
	}

	public override bool CanConvertTo(ITypeDescriptorContext context, Type destinationType)
	{
		if ((object)destinationType != typeof(string) && (object)destinationType != typeof(InstanceDescriptor))
		{
			return base.CanConvertTo(context, destinationType);
		}
		return true;
	}

	public override object ConvertFrom(ITypeDescriptorContext context, CultureInfo culture, object value)
	{
		if (culture == null)
		{
			culture = CultureInfo.CurrentCulture;
		}
		if (!(value is string text))
		{
			return base.ConvertFrom(context, culture, value);
		}
		string text2 = text.Trim();
		char[] separator = new char[1] { culture.TextInfo.ListSeparator[0] };
		string[] array = text2.Split(separator);
		if (array.Length != 1)
		{
			throw new ArgumentException("Invalid half format.");
		}
		float a_ = (float)TypeDescriptor.GetConverter(typeof(float)).ConvertFromString(context, culture, array[0]);
		SharpDX.d d2 = new SharpDX.d(a_);
		return d2;
	}

	public override object ConvertTo(ITypeDescriptorContext context, CultureInfo culture, object value, Type destinationType)
	{
		if ((object)destinationType == null)
		{
			throw new ArgumentNullException("destinationType");
		}
		if (culture == null)
		{
			culture = CultureInfo.CurrentCulture;
		}
		if ((object)destinationType == typeof(string) && value is SharpDX.d)
		{
			TypeConverter converter = TypeDescriptor.GetConverter(typeof(float));
			return string.Join(culture.TextInfo.ListSeparator + " ", converter.ConvertToString(context, culture, SharpDX.d.a((SharpDX.d)value)));
		}
		if ((object)destinationType == typeof(InstanceDescriptor) && value is SharpDX.d)
		{
			ConstructorInfo constructor = typeof(SharpDX.d).GetConstructor(new Type[1] { typeof(float) });
			if ((object)constructor != null)
			{
				return new InstanceDescriptor(constructor, new object[1] { SharpDX.d.a((SharpDX.d)value) });
			}
		}
		return base.ConvertTo(context, culture, value, destinationType);
	}
}
