using System;
using Com.Raritan.RcCore;

namespace Com.Raritan.KxGui.Preferences;

public class DevicePreferences
{
	private readonly Com.Raritan.RcCore.o.ColorDepth? _colorDepth;

	private readonly Com.Raritan.RcCore.o.Smoothing? _smoothing;

	private readonly Com.Raritan.RcCore.o.Compression? _connectionSpeed;

	private readonly string _smartCardReaderName;

	private readonly string _ipAddress;

	private readonly string _description;

	private string _dnsName;

	private readonly string _productType;

	private readonly string _port;

	private readonly bool _connectPlaybackDevice;

	private readonly string _playbackDevice;

	private readonly string _playbackFormat;

	private readonly int _playbackBufferSize;

	private readonly bool _connectCaptureDevice;

	private readonly string _captureDevice;

	private readonly string _captureFormat;

	private readonly int _captureBufferSize;

	public Com.Raritan.RcCore.o.ColorDepth? ColorDepth => _colorDepth;

	public Com.Raritan.RcCore.o.Smoothing? Smoothing => _smoothing;

	public Com.Raritan.RcCore.o.Compression? ConnectionSpeed => _connectionSpeed;

	public string SmartCardReaderName => _smartCardReaderName;

	public string IpAddress => _ipAddress;

	public string Description => _description;

	public string DnsName
	{
		get
		{
			return _dnsName;
		}
		internal set
		{
			_dnsName = value;
		}
	}

	public string ProductType => _productType;

	public string Port => _port;

	public bool ConnectPlaybackDevice => _connectPlaybackDevice;

	public string PlaybackDevice => _playbackDevice;

	public string PlaybackFormat => _playbackFormat;

	public int PlaybackBufferSize => _playbackBufferSize;

	public bool ConnectCaptureDevice => _connectCaptureDevice;

	public string CaptureDevice => _captureDevice;

	public string CaptureFormat => _captureFormat;

	public int CaptureBufferSize => _captureBufferSize;

	public bool IsDefault
	{
		get
		{
			Com.Raritan.RcCore.o.ColorDepth? colorDepth = _colorDepth;
			if (!colorDepth.HasValue)
			{
				Com.Raritan.RcCore.o.Compression? connectionSpeed = _connectionSpeed;
				if (!connectionSpeed.HasValue && _description == null && _dnsName == null && _ipAddress == null && _port == null && _productType == null && _smartCardReaderName == null)
				{
					Com.Raritan.RcCore.o.Smoothing? smoothing = _smoothing;
					if (!smoothing.HasValue && _connectPlaybackDevice && _playbackDevice == null && _playbackFormat == null && _playbackBufferSize == 120 && !_connectCaptureDevice && _captureDevice == null && _captureFormat == null)
					{
						return _captureBufferSize == 120;
					}
				}
			}
			return false;
		}
	}

	public DevicePreferences(Com.Raritan.RcCore.o.ColorDepth? colorDepth, Com.Raritan.RcCore.o.Smoothing? smoothing, Com.Raritan.RcCore.o.Compression? connectionSpeed, string smartCardReaderName, string ipAddress, string description, string dnsName, string productType, string port, bool connectPlaybackDevice, string playbackDevice, string playbackFormat, int playbackBufferSize, bool connectCaptureDevice, string captureDevice, string captureFormat, int captureBufferSize)
	{
		XmlDevicePreferences xmlDevicePreferences = new XmlDevicePreferences();
		if (connectionSpeed.HasValue)
		{
			xmlDevicePreferences.ConnectionSpeed = connectionSpeed.ToString();
		}
		if (smoothing.HasValue)
		{
			xmlDevicePreferences.Smoothing = smoothing.ToString();
		}
		if (colorDepth.HasValue)
		{
			xmlDevicePreferences.ColorDepth = colorDepth.ToString();
		}
		xmlDevicePreferences.SmartCardReaderName = smartCardReaderName;
		xmlDevicePreferences.IpAddress = ipAddress;
		xmlDevicePreferences.Description = description;
		xmlDevicePreferences.DnsName = dnsName;
		xmlDevicePreferences.ProductType = ProductType;
		xmlDevicePreferences.Port = Port;
		xmlDevicePreferences.ConnectPlaybackDevice = connectPlaybackDevice;
		xmlDevicePreferences.PlaybackDevice = playbackDevice;
		xmlDevicePreferences.PlaybackFormat = playbackFormat;
		xmlDevicePreferences.PlaybackBufferSize = playbackBufferSize;
		xmlDevicePreferences.ConnectCaptureDevice = connectCaptureDevice;
		xmlDevicePreferences.CaptureDevice = captureDevice;
		xmlDevicePreferences.CaptureFormat = captureFormat;
		xmlDevicePreferences.CaptureBufferSize = captureBufferSize;
		_smartCardReaderName = smartCardReaderName;
		_connectionSpeed = connectionSpeed;
		_smoothing = smoothing;
		_colorDepth = colorDepth;
		_ipAddress = ipAddress;
		_description = description;
		_dnsName = dnsName;
		_productType = productType;
		_port = port;
		_connectPlaybackDevice = connectPlaybackDevice;
		_playbackDevice = playbackDevice;
		_playbackFormat = playbackFormat;
		_playbackBufferSize = playbackBufferSize;
		_connectCaptureDevice = connectCaptureDevice;
		_captureDevice = captureDevice;
		_captureFormat = captureFormat;
		_captureBufferSize = captureBufferSize;
	}

	public override string ToString()
	{
		return string.Concat("DevicePreferences : ColorDepth : ", ColorDepth, Environment.NewLine, "Smoothing : ", Smoothing, Environment.NewLine, "ConnectionSpeed : ", ConnectionSpeed, Environment.NewLine, "SmartCardReaderName : ", SmartCardReaderName, "IpAddress: ", IpAddress, "Description : ", Description, "DnsName : ", DnsName, "ProductType : ", ProductType, "Port : ", Port);
	}

	public override bool Equals(object obj)
	{
		if (obj != null && obj.GetType().Equals(typeof(DevicePreferences)))
		{
			DevicePreferences devicePreferences = obj as DevicePreferences;
			if (object.Equals(ColorDepth, devicePreferences.ColorDepth) && object.Equals(Smoothing, devicePreferences.Smoothing) && object.Equals(ConnectionSpeed, devicePreferences.ConnectionSpeed) && object.Equals(SmartCardReaderName, devicePreferences.SmartCardReaderName) && object.Equals(IpAddress, devicePreferences.IpAddress) && object.Equals(Description, devicePreferences.Description) && object.Equals(DnsName, devicePreferences.DnsName) && object.Equals(ProductType, devicePreferences.ProductType))
			{
				return object.Equals(Port, devicePreferences.Port);
			}
			return false;
		}
		return false;
	}

	public override int GetHashCode()
	{
		return base.GetHashCode();
	}
}
