using System;
using System.IO;
using System.Reflection;
using System.Text;
using System.Xml;
using System.Xml.Schema;
using System.Xml.Serialization;
using System.Xml.XPath;
using System.Xml.Xsl;
using Microsoft.Win32;
using log4net;

namespace Com.Raritan.KxGui.Preferences;

internal class Utils
{
	private static readonly ILog Logger = LogManager.GetLogger(typeof(Utils));

	internal static readonly string HOME_DIR = GetHomeDir();

	private static string GetHomeDir()
	{
		RegistryKey registryKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders");
		if (registryKey != null && registryKey.GetValue("Desktop") is string path)
		{
			return Path.Combine(path, "..");
		}
		return ".";
	}

	internal static XmlDocument GetXmlDocument(string filePath)
	{
		//IL_0000: Unknown result type (might be due to invalid IL or missing references)
		//IL_0006: Expected O, but got Unknown
		//IL_0014: Unknown result type (might be due to invalid IL or missing references)
		//IL_001a: Expected O, but got Unknown
		//IL_00dc: Expected O, but got Unknown
		//IL_0085: Unknown result type (might be due to invalid IL or missing references)
		//IL_008c: Expected O, but got Unknown
		XmlReaderSettings val = new XmlReaderSettings();
		val.ProhibitDtd = false;
		val.XmlResolver = null;
		XmlDocument val2 = new XmlDocument();
		try
		{
			XmlReader val3 = XmlReader.Create(filePath, val);
			try
			{
				val2.Load(val3);
			}
			finally
			{
				((IDisposable)val3)?.Dispose();
			}
		}
		catch (FileNotFoundException)
		{
			Logger.Debug(filePath + " not found");
			return null;
		}
		catch (Exception exception)
		{
			Logger.Warn("Error loading " + filePath, exception);
			return null;
		}
		XmlNode val4 = ((XmlNode)val2).SelectSingleNode("preferences");
		if (val4 != null)
		{
			XmlReaderSettings val5 = new XmlReaderSettings();
			Stream manifestResourceStream = Assembly.GetExecutingAssembly().GetManifestResourceStream("preferences.xsd");
			val5.Schemas.Add((string)null, XmlReader.Create(manifestResourceStream));
			val5.ValidationType = (ValidationType)4;
			XmlReader val6 = XmlReader.Create((TextReader)new StringReader(val4.OuterXml), val5);
			try
			{
				while (val6.Read())
				{
				}
				return val2;
			}
			catch (XmlSchemaValidationException val7)
			{
				XmlSchemaValidationException exception2 = val7;
				Logger.Warn("Error parsing the " + filePath + " , possibly corrupt file", (Exception)(object)exception2);
				return null;
			}
		}
		Logger.Warn("Error parsing the " + filePath + " , possibly corrupt file");
		return null;
	}

	internal static string GetTransformedXml(string xslResourceName, IXPathNavigable data)
	{
		//IL_000c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0012: Expected O, but got Unknown
		//IL_0024: Unknown result type (might be due to invalid IL or missing references)
		//IL_002a: Expected O, but got Unknown
		Stream manifestResourceStream = Assembly.GetExecutingAssembly().GetManifestResourceStream(xslResourceName);
		XslCompiledTransform val = new XslCompiledTransform();
		val.Load(XmlReader.Create(manifestResourceStream));
		StringBuilder stringBuilder = new StringBuilder();
		XmlWriterSettings val2 = new XmlWriterSettings();
		val2.ConformanceLevel = (ConformanceLevel)0;
		val2.OmitXmlDeclaration = false;
		val2.Encoding = Encoding.UTF8;
		XmlWriter val3 = XmlWriter.Create(stringBuilder, val2);
		try
		{
			val.Transform(data, val3);
		}
		catch (XsltException)
		{
		}
		finally
		{
			((IDisposable)val3)?.Dispose();
		}
		return stringBuilder.ToString();
	}

	internal static XmlDocument GetPrefernecesTemplate(string resourceName)
	{
		//IL_0000: Unknown result type (might be due to invalid IL or missing references)
		//IL_0006: Expected O, but got Unknown
		//IL_0012: Unknown result type (might be due to invalid IL or missing references)
		//IL_0018: Expected O, but got Unknown
		XmlDocument val = new XmlDocument();
		using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream(resourceName))
		{
			XmlReaderSettings val2 = new XmlReaderSettings();
			val2.ProhibitDtd = false;
			val2.XmlResolver = null;
			try
			{
				val.Load(XmlReader.Create(stream, val2));
			}
			catch (XmlException)
			{
			}
		}
		return val;
	}

	internal static string Serialize(object o)
	{
		//IL_0006: Unknown result type (might be due to invalid IL or missing references)
		//IL_000c: Expected O, but got Unknown
		//IL_000c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0012: Expected O, but got Unknown
		XmlSerializer val = new XmlSerializer(o.GetType());
		XmlWriterSettings val2 = new XmlWriterSettings();
		val2.ConformanceLevel = (ConformanceLevel)0;
		val2.OmitXmlDeclaration = false;
		val2.Encoding = Encoding.UTF8;
		StringBuilder stringBuilder = new StringBuilder();
		XmlWriter val3 = XmlWriter.Create(stringBuilder, val2);
		try
		{
			val.Serialize(val3, o);
		}
		catch (InvalidOperationException)
		{
		}
		finally
		{
			((IDisposable)val3)?.Dispose();
		}
		return stringBuilder.ToString();
	}

	internal static string GetTransformedXml(string xslResourceName, string data)
	{
		//IL_000c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0012: Expected O, but got Unknown
		//IL_0024: Unknown result type (might be due to invalid IL or missing references)
		//IL_002a: Expected O, but got Unknown
		Stream manifestResourceStream = Assembly.GetExecutingAssembly().GetManifestResourceStream(xslResourceName);
		XslCompiledTransform val = new XslCompiledTransform();
		val.Load(XmlReader.Create(manifestResourceStream));
		StringBuilder stringBuilder = new StringBuilder();
		XmlWriterSettings val2 = new XmlWriterSettings();
		val2.ConformanceLevel = (ConformanceLevel)0;
		val2.OmitXmlDeclaration = false;
		val2.Encoding = Encoding.UTF8;
		XmlWriter val3 = XmlWriter.Create(stringBuilder, val2);
		try
		{
			val.Transform(XmlReader.Create((TextReader)new StringReader(data)), val3);
		}
		catch (XsltException)
		{
		}
		finally
		{
			((IDisposable)val3)?.Dispose();
		}
		return stringBuilder.ToString();
	}
}
