using System;
using System.Xml.Serialization;
using Com.Raritan.RcCore;

namespace Com.Raritan.KxGui.Preferences;

[XmlRoot("DevicePreferences")]
public class XmlDevicePreferences
{
	private const int ValueMaxLength = 8192;

	private string _deviceIp;

	private string _colorDepth;

	private string _smoothing;

	private string _connectionSpeed;

	private string _smartCardReaderName;

	private bool _connectPlaybackDevice = true;

	private int _playbackBufferSize = -1;

	private bool _connectCaptureDevice;

	private int _captureBufferSize = -1;

	public string DeviceIp
	{
		get
		{
			return _deviceIp;
		}
		set
		{
			if (value == null)
			{
				throw new ArgumentNullException("DeviceIp", "DeviceIp Cannot be null");
			}
			_deviceIp = value;
		}
	}

	public string ColorDepth
	{
		get
		{
			return _colorDepth;
		}
		set
		{
			Enum.Parse(typeof(Com.Raritan.RcCore.o.ColorDepth), value, ignoreCase: true);
			_colorDepth = value;
		}
	}

	[XmlIgnore]
	public Com.Raritan.RcCore.o.ColorDepth? ColorDepthAsEnum
	{
		get
		{
			if (ColorDepth == null)
			{
				return null;
			}
			return (Com.Raritan.RcCore.o.ColorDepth)Enum.Parse(typeof(Com.Raritan.RcCore.o.ColorDepth), ColorDepth, ignoreCase: true);
		}
	}

	public string Smoothing
	{
		get
		{
			return _smoothing;
		}
		set
		{
			Enum.Parse(typeof(Com.Raritan.RcCore.o.Smoothing), value, ignoreCase: true);
			_smoothing = value;
		}
	}

	[XmlIgnore]
	public Com.Raritan.RcCore.o.Smoothing? SmoothingAsEnum
	{
		get
		{
			if (Smoothing == null)
			{
				return null;
			}
			return (Com.Raritan.RcCore.o.Smoothing)Enum.Parse(typeof(Com.Raritan.RcCore.o.Smoothing), Smoothing, ignoreCase: true);
		}
	}

	public string ConnectionSpeed
	{
		get
		{
			return _connectionSpeed;
		}
		set
		{
			Enum.Parse(typeof(Com.Raritan.RcCore.o.Compression), value, ignoreCase: true);
			_connectionSpeed = value;
		}
	}

	[XmlIgnore]
	public Com.Raritan.RcCore.o.Compression? ConnectionSpeedAsEnum
	{
		get
		{
			if (ConnectionSpeed == null)
			{
				return null;
			}
			return (Com.Raritan.RcCore.o.Compression)Enum.Parse(typeof(Com.Raritan.RcCore.o.Compression), ConnectionSpeed, ignoreCase: true);
		}
	}

	public string SmartCardReaderName
	{
		get
		{
			return _smartCardReaderName;
		}
		set
		{
			if (value != null && (value.Length > 8192 || value.Length == 0))
			{
				throw new ArgumentOutOfRangeException("SmartCardReaderName", $"Name cannot be empty or more than {8192} characters");
			}
			_smartCardReaderName = value;
		}
	}

	public string IpAddress { get; set; }

	public string Description { get; set; }

	public string DnsName { get; set; }

	public string ProductType { get; set; }

	public string Port { get; set; }

	public bool ConnectPlaybackDevice
	{
		get
		{
			return _connectPlaybackDevice;
		}
		set
		{
			_connectPlaybackDevice = value;
		}
	}

	public string PlaybackDevice { get; set; }

	public string PlaybackFormat { get; set; }

	public int PlaybackBufferSize
	{
		get
		{
			return _playbackBufferSize;
		}
		set
		{
			_playbackBufferSize = value;
		}
	}

	public bool ConnectCaptureDevice
	{
		get
		{
			return _connectCaptureDevice;
		}
		set
		{
			_connectCaptureDevice = value;
		}
	}

	public string CaptureDevice { get; set; }

	public string CaptureFormat { get; set; }

	public int CaptureBufferSize
	{
		get
		{
			return _captureBufferSize;
		}
		set
		{
			_captureBufferSize = value;
		}
	}

	public XmlDevicePreferences()
	{
	}

	internal XmlDevicePreferences(Com.Raritan.RcCore.o.Compression? connectionSpeed, Com.Raritan.RcCore.o.Smoothing? smoothing, Com.Raritan.RcCore.o.ColorDepth? colorDepth, string deviceIp, string smartCardReaderName, string ipAddress, string description, string dnsName, string productType, string port, bool connectPlaybackDevice, string playbackDevice, string playbackFormat, int playbackBufferSize, bool connectCaptureDevice, string captureDevice, string captureFormat, int captureBufferSize)
	{
		if (connectionSpeed.HasValue)
		{
			ConnectionSpeed = connectionSpeed.ToString();
		}
		if (smoothing.HasValue)
		{
			Smoothing = smoothing.ToString();
		}
		if (colorDepth.HasValue)
		{
			ColorDepth = colorDepth.ToString();
		}
		DeviceIp = deviceIp;
		SmartCardReaderName = smartCardReaderName;
		IpAddress = ipAddress;
		Description = description;
		DnsName = dnsName;
		ProductType = productType;
		Port = port;
		ConnectPlaybackDevice = connectPlaybackDevice;
		PlaybackDevice = playbackDevice;
		PlaybackFormat = playbackFormat;
		PlaybackFormat = playbackFormat;
		ConnectCaptureDevice = connectCaptureDevice;
		CaptureDevice = captureDevice;
		CaptureFormat = captureFormat;
		CaptureBufferSize = captureBufferSize;
	}

	internal XmlDevicePreferences(DevicePreferences p, string deviceAddress)
	{
		if (p.ConnectionSpeed.HasValue)
		{
			ConnectionSpeed = p.ConnectionSpeed.ToString();
		}
		if (p.Smoothing.HasValue)
		{
			Smoothing = p.Smoothing.ToString();
		}
		if (p.ColorDepth.HasValue)
		{
			ColorDepth = p.ColorDepth.ToString();
		}
		SmartCardReaderName = p.SmartCardReaderName;
		IpAddress = p.IpAddress;
		Description = p.Description;
		DnsName = p.DnsName;
		ProductType = p.ProductType;
		Port = p.Port;
		DeviceIp = deviceAddress;
		ConnectPlaybackDevice = p.ConnectPlaybackDevice;
		PlaybackDevice = p.PlaybackDevice;
		PlaybackFormat = p.PlaybackFormat;
		PlaybackBufferSize = p.PlaybackBufferSize;
		ConnectCaptureDevice = p.ConnectCaptureDevice;
		CaptureDevice = p.CaptureDevice;
		CaptureFormat = p.CaptureFormat;
		CaptureBufferSize = p.CaptureBufferSize;
	}

	public override string ToString()
	{
		return "XmlDevicePreferences : " + DeviceIp + Environment.NewLine + "ColorDepth : " + ColorDepth + Environment.NewLine + "Smoothing : " + Smoothing + Environment.NewLine + "ConnectionSpeed : " + ConnectionSpeed + Environment.NewLine + "SmartCardReaderName : " + SmartCardReaderName + Environment.NewLine + "IpAddress : " + IpAddress + Environment.NewLine + "Description : " + Description + Environment.NewLine + "DnsName : " + DnsName + Environment.NewLine + "ProductType : " + ProductType + Environment.NewLine + "Port : " + Port + Environment.NewLine + "ConnectPlaybackDevice : " + ConnectPlaybackDevice + Environment.NewLine + "PlaybackDevice : " + PlaybackDevice + Environment.NewLine + "PlaybackFormat : " + PlaybackFormat + Environment.NewLine + "PlaybackBufferSize : " + PlaybackBufferSize + Environment.NewLine + "ConnectCaptureDevice : " + ConnectCaptureDevice + Environment.NewLine + "CaptureDevice : " + CaptureDevice + Environment.NewLine + "CaptureFormat : " + CaptureFormat + Environment.NewLine + "CaptureBufferSize : " + CaptureBufferSize;
	}
}
